@@ -1,14 +1,13 @@
 //! Build support functions for the Rust-Skia library.
 
 pub mod android;
-pub mod azure;
-pub mod binaries;
+pub mod binaries_config;
+#[cfg(feature = "binary-cache")]
+pub mod binary_cache;
 pub mod cargo;
 pub mod clang;
-pub mod git;
+pub mod features;
 pub mod ios;
-pub mod llvm;
 pub mod skia;
-pub mod utils;
-pub mod vs;
+pub mod skia_bindgen;
 pub mod xcode;
