@@ -243,6 +243,32 @@ pub fn generate_bindings(build: &FinalBuildConfiguration, output_directory: &Pat
                 builder = builder.clang_arg(arg);
             }
         }
+        ("wasm32", "unknown", "emscripten", _) => {
+            // visibility=default, otherwise some types may be missing:
+            // https://github.com/rust-lang/rust-bindgen/issues/751#issuecomment-555735577
+            builder = builder.clang_arg("-fvisibility=default");
+
+            let emsdk_base_dir = match std::env::var("EMSDK") {
+                Ok(val) => val,
+                Err(_e) => panic!("please set the EMSDK environment variable to the root of your Emscripten installation"),
+            };
+
+            // Add C++ includes (otherwise build will fail with <cmath> not found)
+            let add_sys_include = |builder: bindgen::Builder, path: &str| -> bindgen::Builder {
+                let cflag = format!(
+                    "-isystem{}/upstream/emscripten/system/{}",
+                    emsdk_base_dir, path
+                );
+                builder.clang_arg(&cflag)
+            };
+
+            builder = builder.clang_arg("-nobuiltininc");
+            builder = add_sys_include(builder, "lib/libc/musl/arch/emscripten");
+            builder = add_sys_include(builder, "lib/libc/musl/arch/generic");
+            builder = add_sys_include(builder, "lib/libcxx/include");
+            builder = add_sys_include(builder, "lib/libc/musl/include");
+            builder = add_sys_include(builder, "include");
+        }
         _ => {}
     }
 
